summaryrefslogtreecommitdiffstats
Side-by-side diff
-rw-r--r--README2
-rw-r--r--TODO1
-rw-r--r--src/controller/actions/sel_save.sqc3
-rw-r--r--src/controller/callbacks/mouse.c10
-rw-r--r--src/model/data/base.sqc3
5 files changed, 12 insertions, 7 deletions
diff --git a/src/controller/callbacks/mouse.c b/src/controller/callbacks/mouse.c
index 5f5be43..5b1a794 100644
--- a/src/controller/callbacks/mouse.c
+++ b/src/controller/callbacks/mouse.c
@@ -20,12 +20,16 @@
void
mouse (int button, int state, int x, int y)
{
- // Release left button.
- if (button == GLUT_LEFT_BUTTON && state == GLUT_UP)
+ // Release right button.
+ if (button == GLUT_RIGHT_BUTTON && state == GLUT_UP)
{
// Deactive a panning event if one was happening.
S.pan.active = false;
+ }
+ // Release left button.
+ if (button == GLUT_LEFT_BUTTON && state == GLUT_UP)
+ {
if (S.selection.active &&
S.selection.purpose == ZOOM &&
glutGetModifiers () == GLUT_ACTIVE_CTRL)
@@ -170,7 +174,7 @@ mouse (int button, int state, int x, int y)
}
// Pan.
- if (button == GLUT_LEFT_BUTTON &&
+ if (button == GLUT_RIGHT_BUTTON &&
state == GLUT_DOWN && glutGetModifiers () != GLUT_ACTIVE_CTRL)
{
/*

Valid XHTML 1.0 Strict

Copyright © 2009 Don Pellegrino All Rights Reserved.